<?php

namespace EuKit\Base\ViewModels;

use EuKit\Base\Parts\Image;
use EuKit\Base\Parts\ArticleBodyPresentation;
use Infomaker\Everyware\Support\Interfaces\PropertyObject;

/**
 * Class ArticlePage
 * @package EuKit\Base
 */
class ArticlePage extends Page
{
    public function __construct(PropertyObject $article)
    {
        $articleBody = $article->getParsedBody();
        $articleBodyPresentation = new ArticleBodyPresentation($article);

        $article->fill([
            'teaserImage' => $this->getTeaserImage($article),
            'body' => $articleBody->generateContent($articleBodyPresentation),
            'relatedArticles' => $articleBody->allOfType('x-im/articlex'),
            'authors' => $article->authors->toArray(),
        ]);

        parent::__construct($article);
    }

    protected function getTeaserImage($article)
    {
        $articleTeaser = $article->getNewsMLTeaser();
        $image = $articleTeaser ? $articleTeaser->getImage() : null;

        if ($image !== null) {
            $image->set('text', $articleTeaser->title);
            $image = new Image($image);
        }

        return $image ? $image->getViewData() : null;
    }
}
